@@ -50,12 +50,15 @@ INTERNALERROR_QUOTASYSTEM = 'InternalError.QuotaSystem'
 # 后端服务路由地址错误。
 INTERNALERROR_ROUTEERROR = 'InternalError.RouteError'
 
-# 内部错误。
+# 系统错误。
 INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
 
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 操作频繁，请稍后重试。
+INVALIDPARAMETER_ACTIONINPROGRESS = 'InvalidParameter.ActionInProgress'
+
 # 域名不存在或不属于该账号。
 INVALIDPARAMETER_DOMAINNOTFOUND = 'InvalidParameter.DomainNotFound'
 
@@ -68,18 +71,51 @@ INVALIDPARAMETER_INVALIDCERTINFO = 'InvalidParameter.InvalidCertInfo'
 # 无效的客户端IP请求头。
 INVALIDPARAMETER_INVALIDCLIENTIPHEADERNAME = 'InvalidParameter.InvalidClientIpHeaderName'
 
+# 套餐包不支持智能加速配置。
+INVALIDPARAMETER_INVALIDDYNAMICROUTINEBILLING = 'InvalidParameter.InvalidDynamicRoutineBilling'
+
+# 不合法的过滤字段。
+INVALIDPARAMETER_INVALIDFILTERNAME = 'InvalidParameter.InvalidFilterName'
+
+# 无效的强制HTTPS跳转。
+INVALIDPARAMETER_INVALIDFORCEREDIRECTTYPE = 'InvalidParameter.InvalidForceRedirectType'
+
 # 无效的源站。
 INVALIDPARAMETER_INVALIDORIGIN = 'InvalidParameter.InvalidOrigin'
 
 # 套餐包不支持最大上传大小。
 INVALIDPARAMETER_INVALIDPOSTMAXSIZEBILLING = 'InvalidParameter.InvalidPostMaxSizeBilling'
 
+# 无效的最大上传大小。
+INVALIDPARAMETER_INVALIDPOSTSIZEVALUE = 'InvalidParameter.InvalidPostSizeValue'
+
+# 无效的URL重写。
+INVALIDPARAMETER_INVALIDREDIRECTURLCAPTURE = 'InvalidParameter.InvalidRedirectUrlCapture'
+
 # 无效的请求头header。
 INVALIDPARAMETER_INVALIDREQUESTHEADERNAME = 'InvalidParameter.InvalidRequestHeaderName'
 
+# 无效的请求头header。
+INVALIDPARAMETER_INVALIDREQUESTHEADERVALUE = 'InvalidParameter.InvalidRequestHeaderValue'
+
 # 无套餐包。
 INVALIDPARAMETER_INVALIDRESOURCEIDBILLING = 'InvalidParameter.InvalidResourceIdBilling'
 
+# 无效的响应头header。
+INVALIDPARAMETER_INVALIDRESPONSEHEADERVALUE = 'InvalidParameter.InvalidResponseHeaderValue'
+
+# 无效的规则引擎操作。
+INVALIDPARAMETER_INVALIDRULEENGINEACTION = 'InvalidParameter.InvalidRuleEngineAction'
+
+# 无效的规则引擎条件。
+INVALIDPARAMETER_INVALIDRULEENGINETARGET = 'InvalidParameter.InvalidRuleEngineTarget'
+
+# 无效的规则引擎文件后缀条件。
+INVALIDPARAMETER_INVALIDRULEENGINETARGETSEXTENSION = 'InvalidParameter.InvalidRuleEngineTargetsExtension'
+
+# URL重写的目标URL无效。
+INVALIDPARAMETER_INVALIDURLREDIRECTURL = 'InvalidParameter.InvalidUrlRedirectUrl'
+
 # 无效的WebSocket。
 INVALIDPARAMETER_INVALIDWEBSOCKETTIMEOUT = 'InvalidParameter.InvalidWebSocketTimeout'
 
@@ -128,6 +164,9 @@ INVALIDPARAMETERVALUE_INVALIDPROXYNAME = 'InvalidParameterValue.InvalidProxyName
 # DNS 代理域名源站错误。
 INVALIDPARAMETERVALUE_INVALIDPROXYORIGIN = 'InvalidParameterValue.InvalidProxyOrigin'
 
+# SRV 记录名称错误。
+INVALIDPARAMETERVALUE_INVALIDSRVNAME = 'InvalidParameterValue.InvalidSRVName'
+
 # 记录已存在。
 INVALIDPARAMETERVALUE_RECORDALREADYEXISTS = 'InvalidParameterValue.RecordAlreadyExists'
 
